.. role:: small

Version 0.1.2 :small:`Aug 21, 2018`
-----------------------------------

This is a first alpha release of scvelo which provides estimation and analysis of stochastic RNA velocity in single cells.